@@ -31,6 +31,10 @@ ITEM_CACHE_CONTROL = ''
 
 RESOURCE_METHODS = ['GET']
 ITEM_METHODS = ['GET']
+PUBLIC_METHODS = []
+ALLOWED_ROLES = None
+PUBLIC_ITEM_METHODS = []
+ALLOWED_ITEM_ROLES = None
 ITEM_LOOKUP = True
 ITEM_LOOKUP_FIELD = ID_FIELD
 ITEM_URL = '[a-f0-9]{24}'
