@@ -13,4 +13,4 @@
 from get import get, getitem
 from post import post
 from patch import patch
-from delete import delete
+from delete import delete, delete_resource
