@@ -7,7 +7,7 @@ import string
 import random
 import simplejson as json
 from datetime import datetime, timedelta
-from flask.ext.pymongo import Connection
+from flask.ext.pymongo import MongoClient
 from bson import ObjectId
 from eve import Eve, STATUS_ERR
 from test_settings import MONGO_PASSWORD, MONGO_USERNAME, MONGO_DBNAME, DOMAIN
@@ -45,6 +45,11 @@ class TestBase(unittest.TestCase):
         self.readonly_resource_url = (
             '/%s/' % self.domain[self.readonly_resource]['url'])
 
+        self.different_resource = 'users'
+        self.different_resource_url = ('/%s/' %
+                                       self.domain[
+                                           self.different_resource]['url'])
+
     def assert200(self, status):
         self.assertEqual(status, 200)
 
@@ -82,6 +87,16 @@ class TestMethodsBase(TestBase):
         self.readonly_id_url = ('%s%s/' % (self.readonly_resource_url,
                                            self.readonly_id))
 
+        response, status = self.get('users')
+        user = response['_items'][0]
+        self.user_id = user[self.app.config['ID_FIELD']]
+        self.user_username = user['username']
+        self.user_name = user['ref']
+        self.user_etag = user['etag']
+        self.user_id_url = ('/%s/%s/' %
+                            (self.domain[self.different_resource]['url'],
+                             self.user_id))
+
     def tearDown(self):
         self.dropDB()
 
@@ -224,7 +239,7 @@ class TestMethodsBase(TestBase):
         self.assertEqual(status, 412)
 
     def setupDB(self):
-        self.connection = Connection()
+        self.connection = MongoClient()
         self.connection.drop_database(MONGO_DBNAME)
         self.connection[MONGO_DBNAME].add_user(MONGO_USERNAME, MONGO_PASSWORD)
         self.bulk_insert()
@@ -232,11 +247,12 @@ class TestMethodsBase(TestBase):
     def bulk_insert(self):
         _db = self.connection[MONGO_DBNAME]
         _db.contacts.insert(self.random_contacts(100))
+        _db.contacts.insert(self.random_users(2))
         _db.payments.insert(self.random_payments(10))
         self.connection.close()
 
     def dropDB(self):
-        self.connection = Connection()
+        self.connection = MongoClient()
         self.connection.drop_database(MONGO_DBNAME)
         self.connection.close()
 
@@ -266,6 +282,12 @@ class TestMethodsBase(TestBase):
             contacts.append(contact)
         return contacts
 
+    def random_users(self, num):
+        users = self.random_contacts(num)
+        for user in users:
+            user['username'] = self.random_string(10)
+        return users
+
     def random_payments(self, num):
         payments = []
         for i in range(num):
@@ -290,7 +312,7 @@ class TestMethodsBase(TestBase):
         return alist
 
     def random_rows(self, num):
-        schema = DOMAIN['contacts']['schema']['rows']['items']
+        schema = DOMAIN['contacts']['schema']['rows']['schema']['schema']
         rows = []
         for i in range(num):
             rows.append(
